pub struct Curator { /* private fields */ }Implementations
Sourceimpl Curator
impl Curator
pub fn new() -> Self
Sourcepub fn curate(&self, skills_dir: &Path) -> Result<()>
pub fn curate(&self, skills_dir: &Path) -> Result<()>
Grade, consolidate, dedupe, and prune the skill library. This is the closed learning loop — skills are created from experience and improved during use.
Sourcepub fn propose_skill(run_description: &str, outcome: &str) -> Option<Skill>
pub fn propose_skill(run_description: &str, outcome: &str) -> Option<Skill>
Generate a skill candidate from a successful run trajectory.
Called by the engine after a RunFinished event.
pub fn propose_skill_if_missing( run_description: &str, outcome: &str, library: &dyn SkillLibrary, ) -> Option<Skill>