pub enum RunRoutingOutcome {
VerifiedSuccess,
Escalated,
Failed,
}Expand description
Outcome of a run, as far as routing quality is concerned.
Variants
VerifiedSuccess
The run finished and the verify command passed without escalation.
Escalated
The run finished but only after escalating to a stronger model.
Failed
The run failed (verification never passed, or the chain errored out).