Multi-agent lane display for streaming output.
Shows multiple concurrent agent progress lanes in the terminal,
similar to docker compose logs or htop.
Structs
- Lane
Display - Displays multiple agent lanes concurrently.
Multi-agent lane display for streaming output.
Shows multiple concurrent agent progress lanes in the terminal,
similar to docker compose logs or htop.