Text-to-Speech tool for Sparrow.
Converts text to speech audio using various providers (edge-tts by default). Saves audio files in the Sparrow state directory.
Enums
- TtsProvider
- Available TTS providers.
Functions
- text_
to_ speech - Convert text to speech and save to a file.