Module code

Module code 

Functions

highlight
Highlight a code string with syntax highlighting, producing an ANSI-coloured String suitable for terminal output.
highlight_with_line_numbers
Highlight a code string with line numbers prepended on the left.