CLI Rich Rendering Engine for Sparrow.
Provides terminal-native rendering of markdown, code with syntax highlighting, diffs, JSON, tables, and key-value pairs.
CLI Rich Rendering Engine for Sparrow.
Provides terminal-native rendering of markdown, code with syntax highlighting, diffs, JSON, tables, and key-value pairs.