pub struct Tui { /* private fields */ }Implementations
Sourceimpl Tui
impl Tui
pub fn new() -> Self
Sourcepub fn with_replay(self, events: Vec<Event>) -> Self
pub fn with_replay(self, events: Vec<Event>) -> Self
Launch the TUI as a replay scrubber over a recorded transcript. ←/→ step through events; Home/End jump to start/end.
Sourcepub fn agent_matches(&self) -> Vec<String>
pub fn agent_matches(&self) -> Vec<String>
@<name> agent picker: returns owned strings prefixed with @. Separate
from the slash autocomplete because the candidate list is dynamic.
Sourcepub fn with_agents(self, names: Vec<String>) -> Self
pub fn with_agents(self, names: Vec<String>) -> Self
Populate the @<name> agent picker with the agents the host knows about.
pub fn with_channels( self, task_tx: UnboundedSender<String>, event_rx: UnboundedReceiver<Event>, ) -> Self
pub fn push_event(&mut self, event: Event)
pub fn run(&mut self) -> Result<()>