pub fn fetch_pr_diff(pr: u64) -> Result<String>
Fetch the diff for pr via gh pr diff <pr>. Returns the stdout text on success, otherwise an error that includes stderr — never a silent empty string.
pr
gh pr diff <pr>